<div class="backup-volumes dropdown">
  <ul class="dropdown-menu">
    <li class="last">
      <div class="volume new-volume">
        <div class="item button no-select">
          <div class="info">Create New Backup Volume</div>
        </div>
      </div>
    </li>
  </ul>
</div>
<div class="new-snapshot-box">
  <div class="new-snapshot button no-select">New Snapshot</div>
  <div class="error">
    Failed to create new snapshot. Check log for more information.
  </div>
</div>
