<%
if (typeof title === 'undefined') {
  var title = id;
}

if (typeof subText === 'undefined') {
  var subText = '';
}
else {
  subText = '(' + subText + ')';
}
%>
<div class="title">
  <span class="id-text"><%= title %></span>
  <i class="close-viewer icon-remove no-select"></i>
  <i class="change-theme icon-picture no-select"></i>
  <span class="sub-text"><%= subText %></span>
</div>
<div class="data">
  <% if (syntax) { %>
    <div class="editor"><%= data %></div>
  <% } else { %>
    <div class="plaintext">
      <pre><%= data %></pre>
    </div>
  <% } %>
</div>
