<div class="navbar navbar-inverse">
  <div class="navbar-inner">
    <div class="container">
      <a class="brand" href="#"><i class="brand-img"></i></a>
      <ul class="nav">
        <li class="backups"><a href="#">Backups</a></li>
        <li class="about"><a href="#/about">About</a></li>
      </ul>
    </div>
  </div>
</div>
