@default-fg: #e3e3e3;
@default-bg: #ffffff;
@black-fg: #000000;
@lighter-fg: #ffffff;
@darker-fg: #222222;

@loadbar-bg: rgba(0, 114, 230, 0.95);
@loadbar-shadow: 0 0 6px #0065ca;

@navbar-bg-solid: #090909;
@navbar-bg-start: #090909;
@navbar-bg-stop: #1a1a1a;
@navbar-border: solid 1px #1b1b1b;
@navbar-nav-active-bg: #141414;
@navbar-nav-active-hover-bg: #181818;

@page-min-width: 1200px;
@object-drop-min-width: 449px;
@object-text-view-min-width: @object-drop-min-width;
@log-text-view-min-width: 728px;

@selection-bg: #313233;

@input-fg: @lighter-fg;
@input-bg: rgba(51, 51, 51, 0.3);
@input-border: 1px solid #cccccc;

@button-fg: #ffffff;
@button-bg: #0072e6;
@button-hover-bg: #0065cc;
@button-active-bg: #3893d6;
@button-disabled-bg: #6c8daf;

@slider-bg: rgba(51, 51, 51, 0.8);
@placeholder-fg: #c9c9c9;

@error-bg: #ff2423;

@red-tooltip-bg: #ac0000;

@box-bg: rgba(0, 114, 230, 0.55);
@box-border: 1px solid @button-bg;

@error-box-bg: rgba(255, 36, 35, 0.7);
@error-box-bg2: rgba(255, 36, 35, 0.9);
@error-box-border: 1px solid #ff2423;

@meter-fg: rgba(76, 76, 76, 0.60);
@meter-bg: rgba(196, 196, 196, 0.25);
@meter-alert-fg: rgba(255, 107, 107, 0.35);
@meter-alert-bg: rgba(255, 57, 50, 0.60);
@meter-running-bg: rgba(0, 255, 0, 0.7);

@path-select-hover-bg: rgba(0, 0, 0, 0.5);

@loading-bg: rgba(0, 67, 129, 0.55);
@loading-border: solid 1px rgba(0, 49, 111, 0.75);

@inactive-volume-bg: rgba(0, 107, 217, 0.70);

@notification-bg: #ff2b2a;
@notification-hover-bg: #de2525;
@notification-active-bg: #ff3735;
@notification-flash-bg: #ffffff;

@remove-bg: #d30907;
@remove-hover-bg: #960605;
@remove-active-bg: #df3736;

@item-pending-bg: #018f23;
@item-pending-hover-bg: #01691a;
@item-pending-active-bg: #17a138;
@item-pending-box-bg: rgba(1, 143, 35, 0.5);
@item-pending-box-border: 1px solid @item-pending-bg;

@item-aborting-bg: #4e4e4e;
@item-aborting-hover-bg: #3c3c3c;
@item-aborting-active-bg: #686868;
@item-aborting-box-bg: rgba(78, 78, 78, 0.5);
@item-aborting-box-border: 1px solid @item-aborting-bg;

@item-failed-bg: #f53205;
@item-failed-hover-bg: #c72904;
@item-failed-active-bg: #ff4117;
@item-failed-box-bg: rgba(245, 50, 5, 0.5);
@item-failed-box-border: 1px solid @item-failed-bg;

@item-removing-bg: #d30907;
@item-removing-hover-bg: #960605;
@item-removing-active-bg: #fc2e2c;
@item-removing-box-bg: rgba(211, 9, 7, 0.5);
@item-removing-box-border: 1px solid @item-removing-bg;

@item-id-fg: #ebebeb;

@object-fg: #222222;
@object-border: solid 1px #ababab;
@object-hover-border: solid 1px #858585;
@object-selected-bg: #c5e4fc;

@object-path-fg: #777777;

@object-drop-bg: rgba(0, 114, 230, 0.12);
@object-drop-hover-bg: rgba(0, 114, 230, 0.25);
@object-drop-border: 2px dashed #474747;

@object-drop-text-bg: rgba(73, 255, 65, 0.65);
@object-drop-text-border: 2px solid #474747;

@drag-box-fg: #474747;
@drag-box-bg: rgba(255, 255, 255, 0.9);
@drag-box-shadow: 0px 0px 5px 1px #B0B0B0;
