<i class="left-icon <%= icon %> icon-white"></i>
<div class="setting">
  <div class="slider-box">
    <input type="text" name="<%= name %>" title="<%= title %>">
    <div class="slider"></div>
  </div>
</div>
