<div class="object-list-box">
  <table>
    <colgroup>
      <col class="select-col-group"></col>
      <col class="title-col-group"></col>
      <col class="size-col-group"></col>
      <col class="modified-col-group"></col>
    </colgroup>
    <thead>
      <tr>
        <th class="select-header">
          <div class="select">
            <div class="select-inner"></div>
          </div>
        </th>
        <th class="title-header">
          <div class="title-title">TITLE</div>
        </th>
        <th class="size-header">
          <div class="size-title">SIZE</div>
        </th>
        <th class="modified-header">
          <div class="modified-title">LAST MODIFIED</div>
        </th>
      </tr>
    </thead>
    <tbody></tbody>
  </table>
</div>
