<div class="item-box">
  <div class="item button">
    <div class="title no-select"><%= title %></div>
    <i class="view-log icon-list-alt no-select"></i>
    <i class="toggle-info icon-chevron-down no-select"></i>
    <i class="icon icon-remove no-select"></i>
    <i class="icon icon-stop no-select"></i>
  </div>
  <div class="info"><%= info %></div>
</div>
