<div class="item-box <%= state %>">
  <div class="item button">
    <div class="title no-select"><%= formatTime(id) %></div>
    <i class="view-log icon-list-alt no-select"></i>
    <i class="toggle-info icon-chevron-down no-select"></i>
    <i class="icon icon-remove no-select"></i>
    <i class="icon icon-stop no-select"></i>
  </div>
  <div class="info">
    Sent: <%= sent %><br>
    Received: <%= received %><br>
    Speed: <%= speed %><br>
    Runtime: <%= runtime %><br>
    ID: <%= id %>
    <% if (state === 'warning') { %>
      <br>
      <b>Completed with warnings.</b>
      <br>
      <b>Check log for more information.</b>
    <%
       }
       else if (state === 'removing') {
    %>
      <br>
      <b>Snapshot is being removed.</b>
    <% } %>
  </div>
</div>
