<div class="item-list-box">
  <div class="list-title no-select">
    <span><%= title %></span>
    <i class="icon-white icon-minus"></i>
    <div class="notification"></div>
  </div>
  <ul class="item-list"></ul>
  <div class="remove-selected no-select"><%= removeTitle %></div>
</div>
