<i class="left-icon <%= icon %> icon-white"></i>
<div class="setting">
  <input type="<%= password ? 'password' : 'text' %>" name="<%= name %>" value="<%= value %>"
    title="<%= title %>" placeholder="<%= title %>">
</div>
