<%
var titleClass = 'file';
var isDir = false;
if (type && type.indexOf('directory') !== -1) {
  isDir = true;
  titleClass = 'dir';
}
else if (syntax) {
  titleClass = 'text';
}
%>
<td class="select-col">
  <div class="select">
    <div class="select-inner"></div>
  </div>
</td>
<td class="title-col">
  <div class="title-col-box <%= titleClass %>-name">
    <span class=><%= id %></span>
  </div>
</td>
<td class="size-col"><%= isDir ? '' : formatSize(size) %></td>
<td class="modified-col"><%= isDir ? '' : formatTime(time, true) %></td>
