<div class="backup container-fluid">
  <div class="row-fluid">
    <div class="sidebar span3">
      <div class="volumes-box"></div>
      <div class="snapshots-box"></div>
      <div class="tasks-box"></div>
    </div>
    <div class="past span4">
    </div>
    <div class="origin span4">
    </div>
  </div>
</div>
